@@ -258,6 +258,13 @@ class milatools:
         # [positional]
         path: Option
 
+        # Command to use to start vscode
+        # (defaults to "code" or the value of $MILATOOLS_CODE_COMMAND)
+        command: Option = None
+
+        if command is None:
+            command = os.environ.get("MILATOOLS_CODE_COMMAND", "code")
+
         remote = Remote("mila")
         here = Local()
 
@@ -274,7 +281,7 @@ class milatools:
             node_name = f"{node_name}.server.mila.quebec"
         try:
             here.run(
-                "code",
+                command,
                 "-nw",
                 "--remote",
                 f"ssh-remote+{node_name}",
@@ -386,8 +393,7 @@ class milatools:
             # [positional: ?]
             path: Option = default(None)
 
-            path = path or "~"
-            if path.endswith(".ipynb"):
+            if path and path.endswith(".ipynb"):
                 exit("Only directories can be given to the mila serve lab command")
 
             _standard_server(
@@ -409,8 +415,7 @@ class milatools:
             # [positional: ?]
             path: Option = default(None)
 
-            path = path or "~"
-            if path.endswith(".ipynb"):
+            if path and path.endswith(".ipynb"):
                 exit("Only directories can be given to the mila serve notebook command")
 
             _standard_server(
@@ -525,6 +530,8 @@ def _standard_server(
     remote = Remote("mila")
 
     path = path or "~"
+    if path == "~" or path.startswith("~/"):
+        path = remote.home() + path[1:]
 
     with ExitStack() as stack:
         if persist:
